Fastapi Example
=============

The following is a sample of flaat. 

We first use a basic flask code, do some flaat configuration and then use
the decorators provided by flaat.


.. important::

   The sample configuration file is auto-generated from DEEPaaS when this
   documentation is built. You must ensure your version of DEEPaaS matches the
   version of this documentation.

.. literalinclude:: ../../../example-fastapi.py
